pub struct EventBus { /* private fields */ }Expand description
Event bus that can emit events and register event handlers
The event bus is responsible for managing event handlers and emitting events to them. It provides a simple way to register and unregister handlers, and to emit events to all registered handlers.
Examples
struct MyHandler;
#[async_trait]
impl EventHandler for MyHandler {
async fn handle_event(&self, event: &Event) -> Result<(), Error> {
// Handle the event...
Ok(())
}
}
let mut event_bus = EventBus::default();
event_bus.register(Arc::new(MyHandler));
event_bus.emit(&Event::UserCreated(User::builder().id(UserId::new("test")).build().unwrap())).await;Implementations
Sourceimpl EventBus
impl EventBus
Sourcepub async fn register(&self, handler: Arc<dyn EventHandler>)
pub async fn register(&self, handler: Arc<dyn EventHandler>)
Register an event handler with the event bus
Examples
struct MyHandler;
#[async_trait]
impl EventHandler for MyHandler {
async fn handle_event(&self, event: &Event) -> Result<(), Error> {
// Handle the event...
Ok(())
}
}
let mut event_bus = EventBus::default();
event_bus.register(Arc::new(MyHandler));Trait Implementations