pub struct Session {
pub token: SessionToken,
pub user_id: UserId,
pub user_agent: Option<String>,
pub ip_address: Option<String>,
pub created_at: DateTime<Utc>,
pub updated_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
}Fields
token: SessionTokenThe unique identifier for the session.
user_id: UserIdThe unique identifier for the user.
user_agent: Option<String>The user agent of the client that created the session.
ip_address: Option<String>The IP address of the client that created the session.
created_at: DateTime<Utc>The timestamp when the session was created.
updated_at: DateTime<Utc>The timestamp when the session was last updated.
expires_at: DateTime<Utc>The timestamp when the session will expire.
Implementations
Sourceimpl Session
impl Session
pub fn builder() -> SessionBuilder
pub fn is_expired(&self) -> bool
Sourcepub fn to_jwt_claims(
&self,
issuer: Option<String>,
include_metadata: bool,
) -> JwtClaims
pub fn to_jwt_claims( &self, issuer: Option<String>, include_metadata: bool, ) -> JwtClaims
Convert session to JWT claims
Sourcepub fn from_jwt_claims(token: SessionToken, claims: &JwtClaims) -> Self
pub fn from_jwt_claims(token: SessionToken, claims: &JwtClaims) -> Self
Create a session from JWT claims